@@ -58,8 +58,8 @@ def _filefind(filename, path_dirs=None):
         testname = _expand_path(os.path.join(path, filename))
         if os.path.isfile(testname):
             return os.path.abspath(testname)
-
-    raise OSError(f"File {filename!r} does not exist in any of the search paths: {path_dirs!r}")
+    msg = f"File {filename!r} does not exist in any of the search paths: {path_dirs!r}"
+    raise OSError(msg)
 
 
 def _expand_path(s):
